import { Checkout, ShopperCurrency, StoreCurrency } from '@bigcommerce/checkout-sdk';
import React, { FunctionComponent } from 'react';

import { connect } from 'react-redux'

import { withCheckout } from '../checkout';
import { isBuyNowCart } from '../common/utility';
import OrderSummary from '../order/OrderSummary';

import EditLink from './EditLink';
import mapToCartSummaryProps from './mapToCartSummaryProps';
import { RedeemableProps } from './Redeemable';
import withRedeemable from './withRedeemable';

export type WithCheckoutCartSummaryProps = {
    checkout: Checkout;
    cartUrl: string;
    isUpdatedCartSummayModal: boolean;
    storeCurrency: StoreCurrency;
    shopperCurrency: ShopperCurrency;
    storeCreditAmount?: number;
    isInvoice?: boolean;
} & RedeemableProps;

const CartSummary: FunctionComponent<WithCheckoutCartSummaryProps> = ({ cartUrl, isInvoice, ...props }) => {
    const headerLink = isBuyNowCart() ? null : <EditLink url={cartUrl} />;

    return withRedeemable(OrderSummary)({
        ...props,
        cartUrl,
        headerLink,
        isInvoice,
    });
};

const mapStateToProps = (state: { global: { invoiceVersion: number } }) => {
    const {
        global: {
            invoiceVersion,
        },
    } = state

    return {
        isInvoice: invoiceVersion !== 0,
    }
}

export default connect(mapStateToProps, {})(withCheckout(mapToCartSummaryProps)(CartSummary));
